Zones
=====

BrainFrame allows you to specify areas of interest within a video stream and
gain specific insights about that area. Every stream comes with a default zone
called "Screen" which encompasses the full area of the stream. See the `Zones`_
section in the User Manual for more details.

API Methods
-----------

.. automethod:: brainframe.api.BrainFrameAPI.get_zone

.. automethod:: brainframe.api.BrainFrameAPI.get_zones

.. automethod:: brainframe.api.BrainFrameAPI.set_zone

.. automethod:: brainframe.api.BrainFrameAPI.delete_zone

Data Structures
---------------

.. autoclass:: brainframe.api.bf_codecs.zone_codecs.Zone
   :members:

.. _`Zones`:
   https://aotu.ai/docs/user_guide/zones/

